@@ -1,25 +1,13 @@
 f.theta.mixture <- function(K, nb_params, theta) {
   if (is.vector(theta))
     theta <- matrix(theta, nrow = 1)
-  n_total_params <- ncol(theta)
-  n_theta <- nrow(theta)
-  p_vector <- theta[(nb_params + 1):n_total_params]
-  tmp <- theta[1, ]
-  idx <- 1
-  for (i in 1:(K - 1)) {
-    tmp[(nb_params + idx):(nb_params + idx + K - 1)] <- p_vector[i]
-    idx <- idx + K
-  }
-  new_theta <- matrix(nrow = n_theta, ncol = length(tmp))
-  for (i in 1:n_theta) {
+  n_total_params = ncol(theta)
+  new_theta = matrix(nrow(theta),ncol = nb_params+K*(K-1))
+  for (i in 1:nrow(theta)) {
     p_vector <- theta[i, (nb_params + 1):n_total_params]
-    idx <- 1
-    for (j in 1:(K - 1)) {
-      new_theta[i, (nb_params + idx):(nb_params + idx + K - 1)] <- p_vector[j]
-      idx <- idx + K
-    }
+    new_p = rep(p_vector,K)
+    new_theta[i,] = c(theta[i, 1:nb_params],new_p)
   }
-  new_theta[, 1:nb_params] <- theta[, 1:nb_params]
   return(new_theta)
 }
 
